#pragma option -l; // Disable header inclusion in listing
/*
        MPC Code Development System
        Header file for PIC16C64        V1.10

                        16C64.H

        (c) Copyright 1994   Byte Craft Limited
        421 King St.N., Waterloo, ON, Canada, N2J 4E4

        Sherif Abdel-Kader
*/

// 14-bit core
#pragma has PIC14;

// Reset and Interrupt vectors
#pragma vector __RESET @ 0x0000;
#pragma vector __INT   @ 0x0004;

// ROM and RAM size/starting address
#pragma option +l;
#define MAXROM 2043
#pragma memory ROM [MAXROM] @ 0x05;
#pragma memory RAM [96]     @ 0x20;
#pragma memory RAM [32]     @ 0xA0;
#pragma option -l; // Disable rest of header

// Working (W) register
registerw  WREG;

// Special-purpose Registers, Bank 0
#pragma portrw INDF       @ 0x00;
#pragma portrw TMR0       @ 0x01;
#pragma portrw OPTION     @ 0x81;
#pragma portrw PCL        @ 0x02;
#pragma portrw STATUS     @ 0x03;
#pragma portrw FSR        @ 0x04;
#pragma portrw PORTA      @ 0x05;
#pragma portrw PORTB      @ 0x06;
#pragma portrw PORTC      @ 0x07;
#pragma portrw PORTD      @ 0x08;
#pragma portrw PORTE      @ 0x09;
#pragma portrw PCLATH     @ 0x0A;
#pragma portrw INTCON     @ 0x0B;
#pragma portrw PIR1       @ 0x0c;
#pragma portrw TMR1L      @ 0x0E;
#pragma portrw TMR1H      @ 0x0F;
#pragma portrw T1CON      @ 0x10;
#pragma portrw TMR2       @ 0x11;
#pragma portrw T2CON      @ 0x12;
#pragma portrw SSPBUF     @ 0x13;
#pragma portrw SSPCON     @ 0x14;
#pragma portrw CCPR1L     @ 0x15;
#pragma portrw CCPR1H     @ 0x16;
#pragma portrw CCP1CON    @ 0x17 ;

// Special-purpose Registers, Bank 1 : Indirect Addresses
#pragma portrw TRISA      @ 0x85;
#pragma portrw TRISB      @ 0x86;
#pragma portrw TRISC      @ 0x87;
#pragma portrw TRISD      @ 0x88;
#pragma portrw TRISE      @ 0x89;
#pragma portrw PIE1       @ 0x8C;
#pragma portrw PCON       @ 0x8E;
#pragma portrw PR2        @ 0x92;
#pragma portrw SSPADD     @ 0x93;
#pragma portrw SSPSTAT    @ 0x94;

// STATUS register bits
#define C      0
#define DC     1
#define Z      2
#define PD     3
#define TO     4
#define RP0    5
#define RP1    6
#define IRP    7

// OPTION register bits
#define PS0    0
#define PS1    1
#define PS2    2
#define PSA    3
#define RTE    4
#define RTS    5
#define INTEDG 6
#define RBPU   7

//INTCON register bits
#define RBIF   0
#define INTF   1
#define T0IF   2
#define RBIE   3
#define INTE   4
#define T0IE   5
#define PEIE   6
#define GIE    7

// PIE1 register bits
#define TMR1IE 0
#define TMR2IE 1
#define CCP1IE 2
#define SSPIE  3
#define PSPIE  7

// PIR1 register bits
#define TMR1IF 0
#define TMR2IF 1
#define CCP1IF 2
#define SSPIF  3
#define PSPIF  7

// POR register bits
#define POR    1

// PORTA register bits (only special pins)
#define T0CKI  4

// PORTB register bits (only special pins)
#define INT    0

// PORTC register bits (only special pins)
#define T1CKI  0
#define T1CKO  1
#define CCP1   2
#define SCK    3    // Same pin,
#define SCL    3    // different modes
#define SDI    4    // Same pin,
#define SDA    4    // different modes
#define SDO    5

// PORTE register bits (only special pins)
#define RD     0
#define WR     1
#define CS     2

// TRISE register bits
#define TRISE0  0
#define TRISE1  1
#define TRISE2  2
#define PSPMODE 4
#define IBOV    5
#define OBF     6
#define IBF     7

// Enable listing for user program
#pragma option +l;
