#pragma option -l; // Disable header inclusion in listing
/*
        MPC Code Development System
        Header file for PIC16C84        V1.10

                        16C84.H

        (c) Copyright 1994   Byte Craft Limited
        421 King St.N., Waterloo, ON, Canada, N2J 4E4

        Sherif Abdel-Kader
*/

// 14-bit core
#pragma has PIC14;

// Reset and interrupt vectors
#pragma vector __RESET @ 0x0000;
#pragma vector __INT   @ 0x0004;

// ROM and RAM size/starting address
#pragma option +l;
#define MAXROM 1019
#pragma memory ROM [MAXROM]      @ 0x05;
#pragma memory RAM [36]          @ 0x0C;
#pragma option -l; // Disable header inclusion in listing

// Working (W) register
registerw  WREG;

// Special-purpose registers
#pragma portrw INDF   @ 0x00;
#pragma portrw RTCC   @ 0x01;
#pragma portrw OPTION @ 0x81;
#pragma portrw PCL    @ 0x02;
#pragma portrw STATUS @ 0x03;
#pragma portrw FSR    @ 0x04;
#pragma portrw PORTA  @ 0x05;
#pragma portrw TRISA  @ 0x85;
#pragma portrw PORTB  @ 0x06;
#pragma portrw TRISB  @ 0x86;
#pragma portrw EEDATA @ 0x08;
#pragma portrw EEADR  @ 0x09;
#pragma portrw EECON1 @ 0x88;
#pragma portrw EECON2 @ 0x89;
#pragma portrw PCLATH @ 0x0a;
#pragma portrw INTCON @ 0x0b;


// STATUS register bits
#define C      0
#define DC     1
#define Z      2
#define PD     3
#define TO     4
#define RP0    5
#define RP1    6
#define IRP    7

// INTCON register bits
#define RBIF   0
#define INTF   1
#define T0IF   2
#define RBIE   3
#define INTE   4
#define T0IE   5
#define EEIE   6
#define GIE    7

// PORTA register bits (special pins only)
#define T0CKI  4

// PORTB register bits (special pins only)
#define INT    0

// OPTION register bits
#define PS0    0
#define PS1    1
#define PS2    2
#define PSA    3
#define RTE    4
#define RTS    5
#define INTEDG 6
#define RBPU   7

// EECON1 register bits
#define RD     0
#define WR     1
#define WREN   2
#define WRERR  3
#define EEIF   4

// Enable listing for user program
#pragma option +l;

