
/*               K E Y P A D    S C A N
 * Sample typical application code for the MPC Code Development System

       The applications described herein is for illustrative
       purposes only.  Byte Craft Limited makes no representation
       or warranty that such applications will be suitable for the
       specified use without further testing or modification.


 * (c) Copyright 1993
 * Byte Craft Limited
 * Waterloo Ontario CANADA N2J 4E4.
 *
 * Scan the 3x4 keyboard and returns a code made of the column/row
 * in the a register.  The top nibble is the column, the bottom nibble
 * is the row.  If no keys were depressed, it returns 0xFF.

                       Ŀ
                         Ŀ  Ŀ  Ŀ       10K
          B.7 Ĵ 1 Ĵ 2 Ĵ 3 İĿ
                                         
                         Ŀ  Ŀ  Ŀ            
          B.6 Ĵ 4 Ĵ 5 Ĵ 6 İĴ
                                         
                         Ŀ  Ŀ  Ŀ            
          B.5 Ĵ 7 Ĵ 8 Ĵ 9 İĴ
                                         
                         Ŀ  Ŀ  Ŀ            
          B.4 Ĵ * Ĵ 0 Ĵ # İĴ
                                         
          B.3               
                                                       
          B.2             
                                         
          B.1       
                                          
          B.0 

 *
 * returns: The scan code of the key.
 *          The scan code is made up of the column in the top
 *             4 bits with the row in the bottom 4 bits.
 *
 */
#include <17c42.h>

int       tmpa = 0x7f  ;    /* Temporary Location */
int       row  = 0x22  ;    /*  Keyboard row      */
int       column ;          /*  Keyboard column   */
char      index  ;

int scan (void) {
	/* start with the third column */
	for (tmpa = 0x04; tmpa !=0; tmpa >>= 1)
         {                      /* check if key pressed, one col at a time */
          PORTB = tmpa;
          if (row = (PORTB & 0xF0)) /* If key is pressed, get row & column */
            {  column = PORTB & 7;
               for (index = 0; index < 255; index++) ;             /* delay */
	                         /* debounce by checking row with previous */
           if ((PORTB & 0xF0) == row)
                 {  while (PORTB & 0xF0);        /* check for key released */
		    return column | row;	    /* and return the code */
		 }
               else return 0xFF;           /*  not the same, return no key */

            }
	}
	return 0xff;
}

void main ()
  {
    DDRB = 0x0f;           /* Port B bits 7..4 inputs bits 3..0 outputs  */
        while (1) WREG = scan();
  }
