/*
   These routines may be adapted for any purpose when
   used with the MPC Code Development system.  No
   warranty is implied or given as to their usability
   for any purpose.

        (c) Copyright 1995

        Byte Craft Limited
        Waterloo, Ontario
        Canada N2J 4E4
        (519) 888-6911

        Sherif Abdel-Kader
*/

/*
   This program demonstrates mixing C and assembler
   instructions in one source file. Please note:

   1. ASMFUNC1 is an assembler label that can be
      called as a C function. In this case it MUST
      be defined before it is called. Also a RETURN
      instruction must be explicitly added by user.
   2. ASMFUNC2 is a C function with assembler language
      body. This approach is preferred since it
      can be declared with a prototype and forwardly
      referenced. Also a RETURN is automatically coded
      by the compiler.
   3. 'addthem()' is a C function that is called from
      the inline assembler section in main(). Parameters
      are passed through WREG and FSR. The return value
      is placed in the W register.
   4. In assembler references to registers in Bank 1
      cannot be done through their regular #pragma portrw
      statements in the header file. Use their 7-bit address
      instead (e.g. TRISB becomes 0x06, since TRISB in header
      is 0x86 which is out of range in assembler).
*/

#include <16c64.h>

int addthem(void);
void ASMFUNC2();

#asm
ASMFUNC1:
        CLRWDT
        MOVLW 0x00    ; Pins in output mode
        BSF STATUS,RP0; Bank 1 for TRISB
        MOVWF 0x06    ; .. in TRISB
        RETURN        ; Must be added by user
#endasm

void main()
{
 int addresult;

 ASMFUNC1();    // Calling assembler from C
 WREG = 0xAA;
 ASMFUNC2();    // calling assembler with parameter

#asm
   MOVLW 0x55
   MOVWF FSR        ;1st number in FSR
   MOVLW 0xAA       ;2nd number in WREG
   call addthem
   MOVWF addresult  ;result returned in WREG
#endasm
}
 
int addthem(void)
{
  return(WREG + FSR);
}

void ASMFUNC2()
{
#asm
        MOVWF PORTB   ; Output value to port
#endasm
}

