/*
   These routines may be adapted for any purpose when
   used with the MPC Code Development system.  No
   warranty is implied or given as to their usability
   for any purpose.

   This program illustrates implementing
   a multi-level stack for function nesting
   on the PIC16C5x. It is a compilation of application
   note 527, by Stanley D'Souza which is listed in
   Microchip's Embedded Control Handbook.

   (c) Copyright 1995

   Byte Craft Limited
   Waterloo, Ontario
   Canada N2J 4E4
   (519) 888-6911

   Sherif Abdel-Kader

NOTES:
     1) This will only work if the functions
        lie in page 0 as page bits are not
        taken care of by this procedure.

     2) If you modify FSR during the routines
        make sure you save it and restore it.
        FSR is used to keep track of stack
        pointer location.

     3) STACKSIZE is limited by the amount of
        available program memory.

     4) All functions used here are of type
        void, i.e. cannot return values
*/

#include <16C57.h>

// Define stack size
#define STACKSIZE  5

int STACK[STACKSIZE];

void func1(void);
void func2(void);
void func3(void);

#asm
    MACRO NCALL LABEL
          MOVF  PC,W ;Save PC on stack
          MOVWF 0    ;Indirect addressing, FSR
          INCF  FSR  ;Increment stack pointer
          GOTO  LABEL;Jump to routine
    ENDM
#endasm

void main() {

     int x;

     FSR = STACK;  // Let FSR point to STACK
     goto START;   // Jump to main section

// Code for return from function
RET:
#asm
    DECF  FSR
    MOVLW 3
    ADDWF 0,W
    MOVWF PC
#endasm

START:
    // Place your main() code here
    x = 5;
#asm ( NCALL func1 );  // Function call
}


void func1(void)
{
  int y;
  y = 3;
  #asm ( NCALL func2 );
  goto RET;
}

void func2(void)
{
 int z;
 z = 6;
 #asm ( NCALL func3 );
 goto RET;
}

void func3(void)
{
 int w;
 w = 0xAA;
 goto RET;
}

